@@ -1,6 +1,6 @@
 from pathlib import Path
 
-__version__ = "1.0.1"
+__version__ = "1.0.4"
 
 LOGO = (Path(__file__).parent.absolute()/"logo.png").as_posix()
 DATAFILE = Path(__file__).parent.absolute()/"data/untouchable.dat"
@@ -18,7 +18,8 @@ INFO="""نگار قابلیت های زیر را داراست:
 * کلماتی که به اشتباه بدون فاصله به صورت ' میشود '، ' بیشک ' , یا ' نمیرود ' نوشته شده‌، به صورت درست فاصله گذاری میشوند.
 * از استفاده ی بیش از یک علامت ؟؟؟؟ یا !!! جلوگیری می کند.
 * کلماتی که به صورت کشیـــــــــده نوشته شده اند را به صورت درست می نویسد.
-* از فاصله گذاری     بیش از حد    جلوگیری می کند."""
+* از فاصله گذاری     بیش از حد    جلوگیری می کند.
+* علائم نقطه‌گذاری به درستی تنظیم میشوند . بدون فاصله از قبل و با یک فاصله از بعد . استثناء اعداد اعشاری هستند مانند 12.4 که نباید فاصله بگیرد ."""
 
 URLREGX = r""" 	#https://gist.github.com/gruber/8891611
 (?xi)
